@@ -20,24 +20,30 @@ out = Messages()
 
 
 class RADICL(object):
-    '''
+    """
     This is the main interface for end users to interact with the API and the
     probe.
 
     Attributes:
         probe: radicl
-    '''
+    """
+    defaults = {'debug': False}
 
     def __init__(self, **kwargs):
 
-        self.log = get_logger(__name__)
+        self.state = 0
+        for k, v in self.defaults.items():
+            if k not in kwargs.keys():
+                kwargs[k] = v
+
+        self.log = get_logger(__name__, debug=kwargs['debug'])
 
         self.tasks = ['daq', 'settings', 'update']
         self.task_help = {'daq': "Data acquisition using the probe.",
                           'settings': 'Interface for modifying the behavior of the probe',
                           'update': 'Firmware update dialog for the probe.'}
 
-        self.probe = probe.RAD_Probe()
+        self.probe = probe.RAD_Probe(debug=kwargs['debug'])
         self.running = True
 
         self.settings = dir(self.probe)
@@ -51,7 +57,7 @@ class RADICL(object):
         # Assign all data functions with keywords to auto gather data packages
         self.options['data'] = parse_func_list(probe_funcs,
                                                ['read', 'Data'],
-                                               ignore_keywords=['correlation'])
+                                               ignore_keywords=['correlation', 'integrity'])
 
         # Grab the settings from the probe
         self.options['settings'] = self.probe.settings
@@ -82,16 +88,7 @@ class RADICL(object):
         """
         Main running loop for the command line Interface
         """
-
-        self.state = 0
-        plot = False
-        write = False
-        both = False
-        filename_used = False
-        data_attempts = 1
-
         # Create the probe command with an arbitrary command to have access to
-        # help
         while self.running:
 
             pstate = self.probe.getProbeMeasState()
@@ -231,6 +228,7 @@ class RADICL(object):
 
         attempts = 0
         success = False
+        data = None
 
         while attempts < retries and not success:
             self.log.debug(
@@ -241,12 +239,15 @@ class RADICL(object):
                 data = fn()
                 data = self.dataframe_this(data, data_request)
                 success = True
+
             except Exception as e:
                 self.log.warning(
                     'Failed to retrieve {} data, retrying...'.format(data_request))
                 self.log.debug(
                     "Failed {} attempt #{}".format(
                         data_request, attempts))
+                self.log.error(e)
+
                 success = False
                 attempts += 1
 
@@ -254,7 +255,7 @@ class RADICL(object):
             m = ("Unable to retrieve {} data after {} attempts"
                  "".format(data_request, attempts))
             self.log.error(m)
-            raise Exception(m)
+            data = None
 
         return data
 
@@ -278,18 +279,23 @@ class RADICL(object):
         elif self.state == 2:
             self.output_preference = self.ask_user("How do you want to output"
                                                    " {0} data?".format(
-                                                       self.daq),
-                                                   ['plot', 'write', 'both'],
-                                                   default_answer=self.output_preference)
+                self.daq),
+                ['plot', 'write', 'both'],
+                default_answer=self.output_preference)
 
         # Take Measurements
         elif self.state == 3:
             self.take_a_reading()
             self.data = self.grab_data(self.daq)
-            response = self.probe.resetMeasurement()
-
             self.state = 4
 
+            if self.data is None:
+                self.state = 3
+                self.log.error('')
+                self.log.error('Retrieving probe data failed, try again.')
+
+            response = self.probe.resetMeasurement()
+
         # Data output and options
         elif self.state == 4:
             if self.output_preference == 'write' or self.output_preference == 'both':
@@ -331,7 +337,7 @@ class RADICL(object):
                             self.data.to_csv(self.filename, mode='a')
                             self.state = 5
 
-            if self.output_preference == 'plot' or self.output_preference == 'both':
+            if self.output_preference in ['plot', 'both'] and self.state == 4:
                 self.data.plot()
                 plt.show()
                 self.state = 5
@@ -528,7 +534,7 @@ class RADICL(object):
         out.msg("Saving Data to :\n{0}".format(filename))
 
         if not df.empty:
-            # Write the header so we knwo things about this
+            # Write the header so we know things about this
             with open(filename, 'w') as fp:
                 final = self.probe.getProbeHeader()
                 fp.writelines(final)
