@@ -1,7 +1,6 @@
 # coding: utf-8
 
 import sys
-
 import serial
 from serial.tools import list_ports
 
@@ -17,7 +16,6 @@ def find_kw_port(kw):
     Return:
             match_list: list of port names that have at least one matching keyword
     """
-
     match_list = []
 
     # Run through all available COM ports grabs ones that match our keywords
@@ -31,38 +29,37 @@ def find_kw_port(kw):
         if kw_match:
             match_list.append(p)
 
-    # Throw an exception if there are no ports
-    if not match_list:
-        raise IOError("No COM ports found")
-
     return match_list
 
 
-class RAD_Serial():
+class RAD_Serial:
     """
     This class handles all serial communication and simply acts
     as an abstraction layer
     """
 
-    def __init__(self):
+    def __init__(self, debug=False):
         self.serial_port = None
-        self.log = get_logger(__name__, level='DEBUG')
+        self.log = get_logger(__name__, debug=debug)
 
     def openPort(self, com_port=None):
 
         # No COM port has been provided. Need to detect port automatically
-        if (com_port is None):
+        if com_port is None:
             self.log.info("No COM port provided. Scanning for COM ports...")
-
             match_list = find_kw_port(['STMicroelectronics', 'STM32'])
 
             # Check if more than one was found
-            if(len(match_list) > 1):
+            if len(match_list) > 1:
                 self.log.warn('Multiple COM ports found, using the first')
 
+            # If no ports match then error out gracefully
+            elif not match_list:
+                self.log.error("No serial ports were found for the Lyte probe!")
+                raise serial.SerialException('No comports were found!')
+
             # Finally, assign the found port to the serial_port variable
-            this_p = match_list[0]
-            com_port = this_p[0]
+            com_port = match_list[0][0]
 
         try:
             self.log.debug(
@@ -78,52 +75,50 @@ class RAD_Serial():
                                              rtscts=False,
                                              dsrdtr=False)
             self.serial_port.setDTR(1)
+            self.log.info("Using {}".format(self.serial_port.port))
 
         except Exception as e:
-            self.log.error("Serial port open failed: %s" % e)
+            self.log.error("Serial port open failed: {}".format(e))
             raise IOError("Could not open COM port")
 
-            self.log.info("Using %s" % serial_port.port)
-
     def closePort(self):
-        if (self.serial_port is not None):
-            self.serial_port.close
+        if self.serial_port is not None:
+            self.serial_port.close()
             self.serial_port = None
 
     def flushPort(self):
-        if (self.serial_port is not None):
-            self.serial_port.flushOutput()
+        if self.serial_port is not None:
+            self.serial_port.reset_output_buffer()
 
     def writePort(self, data):
         """
         Writes data to the serial port
         """
-
-        if (self.serial_port is not None):
+        if self.serial_port is not None:
             return self.serial_port.write(serial.to_bytes(data))
 
     def writePortClean(self, data):
         """
         Writes data to the serial port, but first clears the input buffer if
-        there is data. This ensures that the next read will be alligned with
+        there is data. This ensures that the next read will be aligned with
         the response from this write
         """
 
-        if (self.serial_port is not None):
-            if (self.self.numBytesInBuffer() > 0):
-                self.self.flushPort()
+        if self.serial_port is not None:
+            if self.numBytesInBuffer() > 0:
+                self.flushPort()
 
             return self.serial_port.write(serial.to_bytes(data))
 
     def readPort(self, numBytes=None):
-        if (self.serial_port is not None):
-            if (numBytes is None):
-                # No number of specifed bytes to read. Read all available bytes
+        if self.serial_port is not None:
+            if numBytes is None:
+                # No number of specified bytes to read. Read all available bytes
                 return self.serial_port.read(self.serial_port.inWaiting())
             else:
                 return self.serial_port.read(numBytes)
 
     def numBytesInBuffer(self):
-        if (self.serial_port is not None):
+        if self.serial_port is not None:
             return self.serial_port.inWaiting()
         return 0
